@@ -17,6 +17,7 @@ class ProfileCommand:
         ververica_url: Optional[str] = None,
         ververica_namespace: Optional[str] = None,
         ververica_deployment_target: Optional[str] = None,
+        ververica_deployment_template_path: Optional[str] = None,
         ververica_api_token: Optional[str] = None,
         docker_registry_url: Optional[str] = None,
         k8s_namespace: Optional[str] = None,
@@ -27,6 +28,7 @@ class ProfileCommand:
             ververica_url=ververica_url,
             ververica_namespace=ververica_namespace,
             ververica_deployment_target=ververica_deployment_target,
+            ververica_deployment_template_path=ververica_deployment_template_path,
             docker_registry_url=docker_registry_url,
             ververica_api_token=ververica_api_token,
             k8s_namespace=k8s_namespace,
