@@ -350,3 +350,49 @@ execution_output = stream_env.from_collection(
 )
 """
         )
+
+    def test_notebook_with_multiple_insert_statements(self):
+        # given
+        file_path = "tests/streamingcli/resources/jupyter/notebook8.ipynb"
+        # expect
+        converted_notebook = convert_notebook(file_path)
+        assert (
+            converted_notebook.content
+            == '''from pyflink.datastream import StreamExecutionEnvironment
+from pyflink.table import StreamTableEnvironment
+
+stream_env = StreamExecutionEnvironment.get_execution_environment()
+stream_env.set_parallelism(1)
+table_env = StreamTableEnvironment.create(stream_env)
+
+
+table_env.execute_sql(f"""CREATE TABLE source1 (
+ num INT
+) WITH (
+    'connector' = 'datagen'
+)""")
+
+
+table_env.execute_sql(f"""CREATE TABLE source2 (
+ num INT
+) WITH (
+    'connector' = 'datagen'
+)""")
+
+
+table_env.execute_sql(f"""CREATE TABLE sink (
+ num INT
+) WITH (
+    'connector' = 'blackhole'
+)""")
+
+
+stmt_set = table_env.create_statement_set()
+
+stmt_set.add_insert_sql(f"""INSERT INTO sink SELECT * FROM source1;""")
+
+stmt_set.add_insert_sql(f"""INSERT INTO sink SELECT * FROM source2;""")
+
+stmt_set.execute()
+'''
+        )
